==> e107-2.1.1_1.txz: usr/local/www/e107/e107_plugins/online/languages/English.php <==
<?php
/*
 * e107 website system
 *
 * Copyright (C) 2008-2009 e107 Inc (e107.org)
 * Released under the terms and conditions of the
 * GNU General Public License (http://www.gnu.org/licenses/gpl.txt)
 *
 * e107 Main
 *
 * $Source: /cvs_backup/e107_0.8/e107_plugins/online/languages/English.php,v $
 * $Revision$
 * $Date$
 * $Author$
*/

//lastseen
define("LAN_LASTSEEN_1", "Last Seen Menu");

//online
define('LAN_ONLINE_TRACKING_MESSAGE', "Online user tracking is currently disabled, please enable it [here]");
define("LAN_ONLINE_1", "Guests: ");
define("LAN_ONLINE_2", "Members: ");
define("LAN_ONLINE_3", "On this page: ");
define("LAN_ONLINE_4", "Online");
define("LAN_ONLINE_5", "");
define("LAN_ONLINE_6", "Newest Member: ");
define("LAN_ONLINE_7", "viewing");
define("LAN_ONLINE_8", "Most ever online: ");
define("LAN_ONLINE_9", "on ");
define("LAN_ONLINE_10", "Online Menu");

//admin
//define("LAN_ONLINE_ADMIN_ENABLED", "enabled");
//define("LAN_ONLINE_ADMIN_DISABLED", "disabled");

//define("LAN_ONLINE_ADMIN_0", "online menu / lastseen menu");
define("LAN_ONLINE_ADMIN_1", "lastseen menu");
define("LAN_ONLINE_ADMIN_2", "Caption lastseen menu");
define("LAN_ONLINE_ADMIN_3", "Number of records to display");
define("LAN_ONLINE_ADMIN_4", "online menu");
define("LAN_ONLINE_ADMIN_5", "Caption online menu");
define("LAN_ONLINE_ADMIN_6", "Show list of members online?");
define("LAN_ONLINE_ADMIN_7", "Show extended list of members online?");
define("LAN_ONLINE_ADMIN_8", "Displays a comma seperated list of members.");
define("LAN_ONLINE_ADMIN_9", "Displays a list of members viewing a page.")


?>

==> e107-2.1.2.txz: usr/local/www/e107/e107_plugins/online/languages/English.php <==
<?php
/*
 * e107 website system
 *
 * Copyright (C) 2008-2009 e107 Inc (e107.org)
 * Released under the terms and conditions of the
 * GNU General Public License (http://www.gnu.org/licenses/gpl.txt)
 *
 * e107 Main
 *
 * $Source: /cvs_backup/e107_0.8/e107_plugins/online/languages/English.php,v $
 * $Revision$
 * $Date$
 * $Author$
*/

//lastseen
define("LAN_LASTSEEN_1", "Last Seen Menu");

//online
define('LAN_ONLINE_TRACKING_MESSAGE', "Online user tracking is currently disabled, please enable it [here]");
define("LAN_ONLINE_1", "Guests: ");
define("LAN_ONLINE_2", "Members: ");
define("LAN_ONLINE_3", "On this page: ");
define("LAN_ONLINE_4", "Online");
define("LAN_ONLINE_5", "");
define("LAN_ONLINE_6", "Newest Member: ");
define("LAN_ONLINE_7", "viewing");
define("LAN_ONLINE_8", "Most ever online: ");
define("LAN_ONLINE_9", "on ");
define("LAN_ONLINE_10", "Online Menu");

define("LAN_ONLINE_11", "Total registered members:");

//admin
//define("LAN_ONLINE_ADMIN_ENABLED", "enabled");
//define("LAN_ONLINE_ADMIN_DISABLED", "disabled");

//define("LAN_ONLINE_ADMIN_0", "online menu / lastseen menu");
define("LAN_ONLINE_ADMIN_1", "lastseen menu");
define("LAN_ONLINE_ADMIN_2", "Caption lastseen menu");
define("LAN_ONLINE_ADMIN_3", "Number of records to display");
define("LAN_ONLINE_ADMIN_4", "online menu");
define("LAN_ONLINE_ADMIN_5", "Caption online menu");
define("LAN_ONLINE_ADMIN_6", "Show list of members online?");
define("LAN_ONLINE_ADMIN_7", "Show extended list of members online?");
define("LAN_ONLINE_ADMIN_8", "Displays a comma seperated list of members.");
define("LAN_ONLINE_ADMIN_9", "Displays a list of members viewing a page.");
define("LAN_ONLINE_ADMIN_10", "Display guests online.");


?>
